use bevy::prelude::*;

#[derive(Resource, Debug, Default)]
pub struct AssetLoader {
    pub sprites: Sprites,
}

#[derive(Resource, Debug, Default)]
pub struct Sprites {
    pub player: Handle<TextureAtlas>,
}

pub struct AssetPlugin;

impl Plugin for AssetPlugin {
    fn build(&self, app: &mut App) {
        app.init_resource::<AssetLoader>()
            .add_systems(Startup, load_assets);
    }
}

fn load_assets(
    mut assets: ResMut<AssetLoader>,
    asset_server: Res<AssetServer>,
    mut texture_atlases: ResMut<Assets<TextureAtlas>>,
) {
    let player_img = asset_server.load("img/Player.png");
    let player_atlas = TextureAtlas::from_grid(
        player_img,
        Vec2::new(32.0, 64.0),
        3,
        1,
        Some(Vec2 { x: 0., y: 0. }),
        Some(Vec2 { x: 0., y: 0. }),
    );
    let player_atlas_handle = texture_atlases.add(player_atlas);
    *assets = AssetLoader {
        sprites: Sprites {
            player: player_atlas_handle,
        },
    };
}
